Analyse Hi-C matrices (API) — FAN-C 0.9.1-beta documentation

# Analyse Hi-C matrices (API)

The `fanc` tool should be accessible from the command line after you installed FAN-C (see Installation). It provides convenient commands for the generation, modification, and analysis of Hi-C data.

Note

The following tutorials assume you have downloaded all the example data files from out GitHub page and ran the sample analysis outlined in Example analysis.

- Expected values and O/E matrices
  - Positional Arguments
  - Named Arguments
  - Example
  - Options
  - Comparing expected values
  - O/E matrices
- AB compartments
  - Positional Arguments
  - Named Arguments
  - Correlation matrix
  - AB Eigenvector
  - AB domains
  - AB enrichment profiles
- PCA
  - Positional Arguments
  - Named Arguments
  - Example
  - Filters
- TADs and TAD boundaries
  - Insulation Score
  - Insulating boundaries (TAD boundaries)
  - Directionality Index
  - A note on TAD calling
- Matrix and score comparisons
  - Positional Arguments
  - Named Arguments
  - Compare matrices
  - Compare scores
  - Compare multi-score files
- Aggregate Hi-C matrices
  - Positional Arguments
  - Named Arguments
  - Aggregate over variable size regions
  - Aggregate TADs
  - Fixed-width regions
  - Loops and other pairwise genomic regions
- Loop calling
  - Positional Arguments
  - Named Arguments
  - Annotating pixels for loop calling
  - Filtering annotated pixels
  - Merging unfiltered pixels into loops
  - Exporting to BEDPE